Learn R Programming

leptokurticMixture (version 1.1)

rmln: Generate realizations from the multivariate elliptical leptokurtic-normal distribution

Description

This function calculates the log cumulative density function for the multivariate-t with scale matrix equal to the identity matrix. It finds the mode and then uses Gaussian quadrature to estimate the integral.

Usage

rmln(n = NULL, d = NULL, mu = NULL, Sigma = NULL, beta = NULL)

Value

A (n x d) matrix of realizations

Arguments

n

number of observations

d

the dimension of the observations

mu

location parameter of length d

Sigma

(d x d) scatter matrix

beta

the concentration parameter

Examples

Run this code
x = rmln(n=10, d=4, mu=rep(0,4), diag(4), beta=2)

Run the code above in your browser using DataLab