rmln: Generate realizations from the multivariate elliptical leptokurtic-normal distribution
Description
This function calculates the log cumulative density function for the multivariate-t with scale matrix equal to the identity matrix. It finds the mode and then uses Gaussian quadrature to estimate the integral.
Usage
rmln(n = NULL, d = NULL, mu = NULL, Sigma = NULL, beta = NULL)